==> kports-0.8.1.tar.bz2: kports-0.8.1/src/instpkgdbreader.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef INSTPKGDBREADER_H
#define INSTPKGDBREADER_H

#include <QString>
#include <QObject>
#include <QProcess>

class QBsdPortInstPkg;

/* Processes the Database of installed packages */

class QInstPkgDbReader : public QObject
{
Q_OBJECT
private:
//     enum QProcess::ExitStatus int

    QProcess            *proc;

    QBsdPortInstPkg     *pkg;
    QString             origin;
    uint                counter;

public:
//     QInstPkgDbReader() : QObject()
//     { 
//         init(); 
//     }
//     QInstPkgDbReader() : QInstPkgDbReader(0) { }
    QInstPkgDbReader(QObject* parent=0);
    QInstPkgDbReader(const QInstPkgDbReader& n);


    void go();

public slots:
    void readStdOut();
    void readStdErr();
    void procFinished(int, QProcess::ExitStatus);

signals:
    void started();
    void finishedSuccessfully(uint);
    void failed(const QString&);
};
#endif //INSTPKGDBREADER_H

==> kports-0.8.2.tar.bz2: kports-0.8.2/src/instpkgdbreader.h <==
/***************************************************************************
 *   Copyright (C) 2005-2009 by Hannes Hauswedell                          *
 *   kports@soulrebel.in-berlin.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef INSTPKGDBREADER_H
#define INSTPKGDBREADER_H

#include <QString>
#include <QObject>
#include <QProcess>

#include "runcmd.h"

class QBsdPortInstPkg;

/* Processes the Database of installed packages */

class QInstPkgDbReader : public BGRunnerBase
{
Q_OBJECT
private:
    QBsdPortInstPkg     *pkg;
    QString             origin;
    uint                counter;

    void processOneLine(const QString&);


public:
    QInstPkgDbReader(QObject* parent=0)
        : BGRunnerBase(parent)
    {
        counter = 0;
        setCmd("/usr/sbin/pkg_info -aQo");
    /* find /var/db/pkg/ -name "+CONTENTS" |
        xargs awk '$1=="@comment" && substr($2,1,6)=="ORIGIN"
            { split(FILENAME,a,"/"); print a[5] ":" substr($2,8) }'
       does the trick aswell and a little faster. Probably not worth losing
       flexibility though */
        connect(this,   SIGNAL(finished(int, QProcess::ExitStatus)),
                this,   SLOT(slotFinished(int, QProcess::ExitStatus)));
    }

private slots:
    inline void slotFinished(int exitCode, QProcess::ExitStatus exitStatus)
    {
        if (exitStatus)
            emit failed(tr("pkg_info -aQo crashed. That's bad."));
        else if (exitCode)
            emit failed(tr("pkg_info -aQo returned %1 which is non-zero."
                        "Who knows what that means.").arg(exitCode));
        else
            emit finishedSuccessfully(counter);
    }

public slots:
    void clearDb();

signals:
    void finishedSuccessfully(uint);
    void failed(const QString&);
};
#endif //INSTPKGDBREADER_H
